summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLuc Verhaegen <libv@skynet.be>2009-12-18 08:37:55 +0000
committerLuc Verhaegen <libv@skynet.be>2009-12-18 08:37:55 +0000
commitb843e2019a957491fcc4d667f9fbd2bb166a6575 (patch)
tree80347136f3454591161ca376303137431cf9db31
parentaa000982f40fa68ceea7ff19d77a0d5965164525 (diff)
downloadast2050-flashrom-b843e2019a957491fcc4d667f9fbd2bb166a6575.zip
ast2050-flashrom-b843e2019a957491fcc4d667f9fbd2bb166a6575.tar.gz
Boards: Add ECS K7S6A
The nulled second set of subsystem ids is correct, and this seems to be a unique match. Corresponding to flashrom svn r808. Signed-off-by: Luc Verhaegen <libv@skynet.be> Acked-by: spirals <spirals@eircom.net>
-rw-r--r--board_enable.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/board_enable.c b/board_enable.c
index 7da1682..8b5ed95 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -987,7 +987,9 @@ static int it8705f_write_enable(uint8_t port, const char *name)
}
/**
* Suited for: Elitegroup K7VTA3: VIA Apollo KT266/A/333 + VIA VT8235 + ITE IT8705F
*/
static int elitegroup_k7vta3(const char *name)
{
@@ -1241,6 +1243,7 @@ struct board_pciid_enable board_pciid_enables[] = {
{0x10DE, 0x0030, 0x1043, 0x818a, 0x8086, 0x100E, 0x1043, 0x80EE, NULL, NULL, "ASUS", "P5ND2-SLI Deluxe", nvidia_mcp_gpio10_raise},
{0x1106, 0x3149, 0x1565, 0x3206, 0x1106, 0x3344, 0x1565, 0x1202, NULL, NULL, "Biostar", "P4M80-M4", it8705_rom_write_enable},
{0x8086, 0x3590, 0x1028, 0x016c, 0x1000, 0x0030, 0x1028, 0x016c, NULL, NULL, "Dell", "PowerEdge 1850", intel_ich_gpio23_raise},
+ {0x1039, 0x5513, 0x1019, 0x0A41, 0x1039, 0x0018, 0, 0, NULL, NULL, "Elitegroup", "K7S6A", elitegroup_k7vta3},
{0x1106, 0x3038, 0x1019, 0x0996, 0x1106, 0x3177, 0x1019, 0x0996, NULL, NULL, "Elitegroup", "K7VTA3", elitegroup_k7vta3},
{0x1106, 0x3177, 0x1106, 0x3177, 0x1106, 0x3059, 0x1695, 0x3005, NULL, NULL, "EPoX", "EP-8K5A2", w836xx_memw_enable_2e},
{0x10EC, 0x8139, 0x1695, 0x9001, 0x11C1, 0x5811, 0x1695, 0x9015, NULL, NULL, "EPoX", "EP-8RDA3+", nvidia_mcp_gpio31_raise},
@@ -987,7 +987,9 @@ static int it8705f_write_enable(uint8_t port, const char *name)
}
/**
- * Suited for: Elitegroup K7VTA3: VIA Apollo KT266/A/333 + VIA VT8235 + ITE IT8705F
+ * Suited for:
+ * - Elitegroup K7S6A: SiS745 + ITE IT8705F
+ * - Elitegroup K7VTA3: VIA Apollo KT266/A/333 + VIA VT8235 + ITE IT8705F
*/
static int elitegroup_k7vta3(const char *name)
OpenPOWER on IntegriCloud